==> easy-antd-modal-1.4.0.tgz: package/lib/mobile/Mask.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/mobile/Mask.tsx
var Mask_exports = {};
__export(Mask_exports, {
  default: () => Mask_default
});
module.exports = __toCommonJS(Mask_exports);
var import_antd_mobile = require("antd-mobile");
var import_hooks = require("../hooks");
function Mask(props) {
  const [visible, { close }, { trigger, content }, restProps] = (0, import_hooks.useModalEnhanced)(props);
  const handleMaskClick = (e) => {
    if (props.onMaskClick)
      return props.onMaskClick(e);
    close();
  };
  const handleMaskClose = () => {
    var _a;
    (_a = props == null ? void 0 : props.afterClose) == null ? void 0 : _a.call(props);
    close();
  };
  return /* @__PURE__ */ React.createElement(React.Fragment, null, trigger, /* @__PURE__ */ React.createElement(
    import_antd_mobile.Mask,
    {
      visible,
      ...restProps,
      afterClose: handleMaskClose,
      onMaskClick: handleMaskClick
    },
    content
  ));
}
var Mask_default = Mask;

==> easy-antd-modal-1.4.1.tgz: package/lib/mobile/Mask.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/mobile/Mask.tsx
var Mask_exports = {};
__export(Mask_exports, {
  default: () => Mask_default
});
module.exports = __toCommonJS(Mask_exports);
var import_antd_mobile = require("antd-mobile");
var import_hooks = require("../hooks");
function Mask(props) {
  const [visible, { close }, { trigger, content }, restProps] = (0, import_hooks.useModalEnhanced)(props);
  const handleMaskClick = (e) => {
    if (props.onMaskClick)
      return props.onMaskClick(e);
    close();
  };
  const handleMaskClose = () => {
    var _a;
    (_a = props.afterClose) == null ? void 0 : _a.call(props);
    close();
  };
  return /* @__PURE__ */ React.createElement(React.Fragment, null, trigger, /* @__PURE__ */ React.createElement(
    import_antd_mobile.Mask,
    {
      visible,
      ...restProps,
      afterClose: handleMaskClose,
      onMaskClick: handleMaskClick
    },
    content
  ));
}
var Mask_default = Mask;
